Description Usage Arguments Value Examples
Parse a fastq format sequence file into a tibble
1 |
file |
A file in fastq format |
A tibble containing the read ids, base calls and quality strings
1 | read_fastq(system.file("good.fq",package="packagetest"))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.